==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/kio/kfile/kimagefilepreview.h <==
/*
 *
 * This file is part of the KDE project.
 * Copyright (C) 2001 Martin R. Jones <mjones@kde.org>
 *               2001 Carsten Pfeiffer <pfeiffer@kde.org>
 *
 * You can Freely distribute this program under the GNU Library General Public
 * License. See the file "COPYING" for the exact licensing terms.
 */

#ifndef KIMAGEFILEPREVIEW_H
#define KIMAGEFILEPREVIEW_H

#include <qpixmap.h>

#include <kurl.h>
#include <kpreviewwidgetbase.h>

class QCheckBox;
class QPushButton;
class QLabel;
class QTimer;

class KFileDialog;
class KFileItem;
class KJob;
namespace KIO { class Job; class PreviewJob; }

/**
 * Image preview widget for the file dialog.
 */
class KIO_EXPORT KImageFilePreview : public KPreviewWidgetBase
{
	Q_OBJECT

	public:
		KImageFilePreview(QWidget *parent);
		~KImageFilePreview();

		virtual QSize sizeHint() const;

	public Q_SLOTS:
		virtual void showPreview(const KUrl &url);
		virtual void clearPreview();

	protected Q_SLOTS:
		void showPreview();
		void showPreview( const KUrl& url, bool force );

		void toggleAuto(bool);
		virtual void gotPreview( const KFileItem*, const QPixmap& );

	protected:
		virtual void resizeEvent(QResizeEvent *e);
		virtual KIO::PreviewJob * createJob( const KUrl& url,
                                                     int w, int h );

	private Q_SLOTS:
		void slotResult( KJob * );
		virtual void slotFailed( const KFileItem* );

	private:
		bool autoMode;
		KUrl currentURL;
		QTimer *timer;
		QLabel *imageLabel;
		QLabel *infoLabel;
		QCheckBox *autoPreview;
		QPushButton *previewButton;
		KIO::PreviewJob *m_job;
        protected:
                virtual void virtual_hook( int id, void* data );
        private:
                class KImageFilePreviewPrivate;
                KImageFilePreviewPrivate *d;
};

#endif // KIMAGEFILEPREVIEW_H

==> kde4libs_3.93.0.orig.tar.gz: kde4libs-3.93.0.orig/kio/kfile/kimagefilepreview.h <==
/*
 *
 * This file is part of the KDE project.
 * Copyright (C) 2001 Martin R. Jones <mjones@kde.org>
 *               2001 Carsten Pfeiffer <pfeiffer@kde.org>
 *
 * You can Freely distribute this program under the GNU Library General Public
 * License. See the file "COPYING" for the exact licensing terms.
 */

#ifndef KIMAGEFILEPREVIEW_H
#define KIMAGEFILEPREVIEW_H

#include <QtGui/QPixmap>

#include <kurl.h>
#include <kpreviewwidgetbase.h>

class KFileItem;
class KJob;
namespace KIO { class PreviewJob; }

/**
 * Image preview widget for the file dialog.
 */
class KIO_EXPORT KImageFilePreview : public KPreviewWidgetBase
{
	Q_OBJECT

	public:
        explicit KImageFilePreview(QWidget *parent);
		~KImageFilePreview();

		virtual QSize sizeHint() const;

	public Q_SLOTS:
		virtual void showPreview(const KUrl &url);
		virtual void clearPreview();

	protected Q_SLOTS:
		void showPreview();
		void showPreview( const KUrl& url, bool force );

		void toggleAuto(bool);
		virtual void gotPreview( const KFileItem&, const QPixmap& );

	protected:
		virtual void resizeEvent(QResizeEvent *e);
		virtual KIO::PreviewJob * createJob( const KUrl& url,
                                                     int w, int h );

	private Q_SLOTS:
		void slotResult( KJob * );
		virtual void slotFailed( const KFileItem& );

        private:
                class KImageFilePreviewPrivate;
        KImageFilePreviewPrivate *const d;

        Q_DISABLE_COPY(KImageFilePreview)
};

#endif // KIMAGEFILEPREVIEW_H
